cast_send_with_access_key

Function cast_send_with_access_key 

pub(crate) async fn cast_send_with_access_key<N: Network, P: Provider<N>>(
    provider: &P,
    tx: N::TransactionRequest,
    signer: &WalletSigner,
    access_key: &TempoAccessKeyConfig,
    cast_async: bool,
    confirmations: u64,
    timeout: u64,
) -> Result<()>
where N::TransactionRequest: FoundryTransactionBuilder<N>, N::ReceiptResponse: UIfmt + UIfmtReceiptExt,
Signs a transaction with a Tempo access key and sends it via send_raw_transaction.

Sets from and key_id on the transaction before signing, making it idempotent for txs built with CastTxBuilder (fields already set) and also with sol!-bindings (fields not yet set).

NOTE: The default implementation returns an error. Only TempoNetwork supports this.