pub(crate) async fn cast_send_with_tempo_wallet_via_sponsor<N: Network, P: Provider<N>>(
provider: &P,
tx: N::TransactionRequest,
wallet: &TempoAccountsWallet,
sponsor_url: &str,
cast_async: bool,
sync: bool,
confirmations: u64,
timeout: u64,
) -> Result<B256>where
N::TransactionRequest: Default + FoundryTransactionBuilder<N>,
N::ReceiptResponse: UIfmt + UIfmtReceiptExt,Expand description
Signs a prepared transaction with a Tempo wallet, obtains a remote fee-payer signature, and broadcasts the sponsored transaction through the original provider transport.